@@ -6,7 +6,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! jieba-rs = "0.6"
+//! jieba-rs = "0.7"
 //! ```
 //!
 //! then you are good to go. If you are using Rust 2015 you have to ``extern crate jieba_rs`` to your crate root as well.
@@ -67,10 +67,11 @@
 //!
 //! ```toml
 //! [dependencies]
-//! jieba-rs = { version = "0.6", features = ["tfidf", "textrank"] }
+//! jieba-rs = { version = "0.7", features = ["tfidf", "textrank"] }
 //! ```
 //!
 
+use include_flate::flate;
 use lazy_static::lazy_static;
 
 use std::cmp::Ordering;
@@ -90,10 +91,6 @@ pub use crate::keywords::tfidf::TfIdf;
 #[cfg(any(feature = "tfidf", feature = "textrank"))]
 pub use crate::keywords::{Keyword, KeywordExtract, KeywordExtractConfig, DEFAULT_STOP_WORDS};
 
-#[cfg(any(feature = "tfidf", feature = "textrank"))]
-#[macro_use]
-extern crate derive_builder;
-
 mod errors;
 mod hmm;
 #[cfg(any(feature = "tfidf", feature = "textrank"))]
@@ -101,7 +98,7 @@ mod keywords;
 mod sparse_dag;
 
 #[cfg(feature = "default-dict")]
-static DEFAULT_DICT: &str = include_str!("data/dict.txt");
+flate!(static DEFAULT_DICT: str from "src/data/dict.txt");
 
 use sparse_dag::StaticSparseDAG;
 
@@ -147,7 +144,7 @@ impl<'t> SplitState<'t> {
     }
 }
 
-impl<'r, 't> Iterator for SplitMatches<'r, 't> {
+impl<'t> Iterator for SplitMatches<'_, 't> {
     type Item = SplitState<'t>;
 
     fn next(&mut self) -> Option<SplitState<'t>> {
@@ -226,7 +223,6 @@ pub struct Jieba {
     records: Vec<Record>,
     cedar: Cedar,
     total: usize,
-    longest_word_len: usize,
 }
 
 #[cfg(feature = "default-dict")]
@@ -243,7 +239,6 @@ impl Jieba {
             records: Vec::new(),
             cedar: Cedar::new(),
             total: 0,
-            longest_word_len: 0,
         }
     }
 
@@ -252,11 +247,8 @@ impl Jieba {
     /// Requires `default-dict` feature to be enabled.
     #[cfg(feature = "default-dict")]
     pub fn new() -> Self {
-        use std::io::BufReader;
-
         let mut instance = Self::empty();
-        let mut default_dict = BufReader::new(DEFAULT_DICT.as_bytes());
-        instance.load_dict(&mut default_dict).unwrap();
+        instance.load_default_dict();
         instance
     }
 
@@ -266,12 +258,71 @@ impl Jieba {
         instance.load_dict(dict)?;
         Ok(instance)
     }
+
+    /// Loads the default dictionary into the instance.
+    ///
+    /// This method reads the default dictionary from a predefined byte slice (`DEFAULT_DICT`)
+    /// and loads it into the current instance using the `load_dict` method.
+    ///
+    /// # Arguments
+    ///
+    /// * `&mut self` - Mutable reference to the current instance.
+    ///
+    /// Requires `default-dict` feature to be enabled.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use jieba_rs::Jieba;
+    ///
+    /// let mut instance = Jieba::empty();
+    /// instance.load_default_dict(); // Loads the default dictionary into the instance
+    /// assert!(instance.has_word("我们"), "The word '我们' should be in the dictionary after loading the default dictionary");
+    /// ```
+    #[cfg(feature = "default-dict")]
+    pub fn load_default_dict(&mut self) {
+        use std::io::BufReader;
+
+        let mut default_dict = BufReader::new(DEFAULT_DICT.as_bytes());
+        self.load_dict(&mut default_dict).unwrap();
+    }
+
+    /// Clears all data
+    ///
+    /// This method performs the following actions:
+    /// 1. Clears the `records` list, removing all entries.
+    /// 2. Resets `cedar` to a new instance of `Cedar`.
+    /// 3. Sets `total` to 0, resetting the count.
+    ///
+    /// # Arguments
+    ///
+    /// * `&mut self` - Mutable reference to the current instance.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use jieba_rs::Jieba;
+    ///
+    /// let mut instance = Jieba::new();
+    /// assert!(instance.has_word("我们"), "The word '我们' should be in the dictionary after loading the default dictionary");
+    /// instance.clear(); // clear all dict data
+    /// assert!(!instance.has_word("我们"), "The word '我们' should not be in the dictionary after clearing the dictionary");
+    /// ```
+    pub fn clear(&mut self) {
+        self.records.clear();
+        self.cedar = Cedar::new();
+        self.total = 0;
+    }
+
     /// Add word to dict, return `freq`
     ///
     /// `freq`: if `None`, will be given by [suggest_freq](#method.suggest_freq)
     ///
     /// `tag`: if `None`, will be given `""`
     pub fn add_word(&mut self, word: &str, freq: Option<usize>, tag: Option<&str>) -> usize {
+        if word.is_empty() {
+            return 0;
+        }
         let freq = freq.unwrap_or_else(|| self.suggest_freq(word));
         let tag = tag.unwrap_or("");
 
@@ -284,27 +335,56 @@ impl Jieba {
                 self.total -= old_freq;
             }
             None => {
+                let word_id = self.records.len() as i32;
                 self.records.push(Record::new(freq, String::from(tag)));
-                let word_id = (self.records.len() - 1) as i32;
 
                 self.cedar.update(word, word_id);
                 self.total += freq;
             }
         };
 
-        let curr_word_len = word.chars().count();
-        if self.longest_word_len < curr_word_len {
-            self.longest_word_len = curr_word_len;
-        }
-
         freq
     }
 
-    /// Load dictionary
+    /// Checks if a word exists in the dictionary.
+    ///
+    /// # Arguments
+    ///
+    /// * `word` - The word to check.
+    ///
+    /// # Returns
+    ///
+    /// * `bool` - Whether the word exists in the dictionary.
+    pub fn has_word(&self, word: &str) -> bool {
+        self.cedar.exact_match_search(word).is_some()
+    }
+
+    /// Loads a dictionary by adding entries to the existing dictionary rather than resetting it.
+    ///
+    /// This function reads from a `BufRead` source, parsing each line as a dictionary entry. Each entry
+    /// is expected to contain a word, its frequency, and optionally a tag.
+    ///
+    /// # Type Parameters
+    ///
+    /// * `R`: A type that implements the `BufRead` trait, used for reading lines from the dictionary.
+    ///
+    /// # Arguments
+    ///
+    /// * `dict` - A mutable reference to a `BufRead` source containing the dictionary entries.
+    ///
+    /// # Returns
+    ///
+    /// * `Result<(), Error>` - Returns `Ok(())` if the dictionary is successfully loaded; otherwise,
+    ///   returns an error describing what went wrong.
+    ///
+    /// # Errors
+    ///
+    /// This function will return an error if:
+    /// * There is an issue reading from the provided `BufRead` source.
+    /// * A line in the dictionary file contains invalid frequency data (not a valid integer).
     pub fn load_dict<R: BufRead>(&mut self, dict: &mut R) -> Result<(), Error> {
         let mut buf = String::new();
         self.total = 0;
-        self.longest_word_len = 0;
 
         let mut line_no = 0;
         while dict.read_line(&mut buf)? > 0 {
@@ -325,18 +405,13 @@ impl Jieba {
                         .unwrap_or(Ok(0))?;
                     let tag = iter.next().unwrap_or("");
 
-                    let curr_word_len = word.chars().count();
-                    if self.longest_word_len < curr_word_len {
-                        self.longest_word_len = curr_word_len;
-                    }
-
                     match self.cedar.exact_match_search(word) {
                         Some((word_id, _, _)) => {
                             self.records[word_id as usize].freq = freq;
                         }
                         None => {
+                            let word_id = self.records.len() as i32;
                             self.records.push(Record::new(freq, String::from(tag)));
-                            let word_id = (self.records.len() - 1) as i32;
                             self.cedar.update(word, word_id);
                         }
                     };
@@ -771,7 +846,7 @@ impl Jieba {
     /// `sentence`: input text
     ///
     /// `hmm`: enable HMM or not
-    pub fn tag<'a>(&'a self, sentence: &'a str, hmm: bool) -> Vec<Tag> {
+    pub fn tag<'a>(&'a self, sentence: &'a str, hmm: bool) -> Vec<Tag<'a>> {
         let words = self.cut(sentence, hmm);
         words
             .into_iter()
@@ -813,6 +888,14 @@ mod tests {
         let _ = Jieba::new();
     }
 
+    #[test]
+    fn test_has_word() {
+        let jieba = Jieba::new();
+        assert!(jieba.has_word("中国"));
+        assert!(jieba.has_word("开源"));
+        assert!(!jieba.has_word("不存在的词"));
+    }
+
     #[test]
     fn test_split_matches() {
         let re_han = &*RE_HAN_DEFAULT;
